## intent:restaurant_search
- i'm looking for a [sushi](food) place to eat
- I want to grab [tacos](food)
- I am searching for a [pizza](food) spot
- I would like to drink [sweet berry wine](beverage) with my meal

## lookup:plates
  data/test/lookup_tables/plates.txt

## lookup:drinks
 - mojito
 - lemonade
 - sweet berry wine
 - tea
 - club mate